@@ -72,7 +72,7 @@ begin_use_class (const char *s, FILE *out)
 {
   if (out == stderr)
     {
-      if (style_debug)
+      if (color_debug)
         fprintf (out, "<%s>", s);
       else
         {
@@ -87,7 +87,7 @@ end_use_class (const char *s, FILE *out)
 {
   if (out == stderr)
     {
-      if (style_debug)
+      if (color_debug)
         fprintf (out, "</%s>", s);
       else
         {
@@ -252,6 +252,7 @@ complain_init_color (void)
 {
 #if HAVE_LIBTEXTSTYLE
   if (color_mode == color_yes
+      || color_mode == color_html
       || (color_mode == color_tty && isatty (STDERR_FILENO)))
     {
       style_file_prepare ("BISON_DIAGNOSTICS_STYLE", NULL,
@@ -268,9 +269,25 @@ complain_init_color (void)
     style_file_name = NULL;
 #endif
 
+  /* Workaround clang's warning (starting at Clang 3.5) about the stub
+     code of html_styled_ostream_create:
+
+     | src/complain.c:274:7: error: code will never be executed [-Werror,-Wunreachable-code]
+     |     ? html_styled_ostream_create (file_ostream_create (stderr),
+     |       ^~~~~~~~~~~~~~~~~~~~~~~~~~ */
+#if defined __clang__
+# pragma clang diagnostic push
+# pragma clang diagnostic ignored "-Wunreachable-code"
+#endif
   errstream =
-    styled_ostream_create (STDERR_FILENO, "(stderr)", TTYCTL_AUTO,
-                           style_file_name);
+    color_mode == color_html
+    ? html_styled_ostream_create (file_ostream_create (stderr),
+                                  style_file_name)
+    : styled_ostream_create (STDERR_FILENO, "(stderr)", TTYCTL_AUTO,
+                             style_file_name);
+#if defined __clang__
+# pragma clang diagnostic pop
+#endif
 }
 
 void
@@ -521,7 +538,7 @@ deprecated_directive (location const *loc, char const *old, char const *upd)
               _("deprecated directive: %s, use %s"),
               quote (old), quote_n (1, upd));
   /* Register updates only if -Wdeprecated is enabled.  */
-  if (warnings_flag[warning_deprecated] != severity_disabled)
+  if (warning_is_enabled (Wdeprecated))
     fixits_register (loc, upd);
 }
 
